==> coronagraph-0.1.tar.gz: coronagraph-0.1/README.md <==
<p align="center">
  <img width = "450" src="https://github.com/jlustigy/coronagraph/blob/luvoir_drm/docs/_static/logo6.png?raw=true"/>
  <br>
  A Python noise model for directly imaging exoplanets with coronagraph equipped telescopes.  
</p>

<p align="center">
  <a href="https://travis-ci.org/jlustigy/coronagraph"><img src="http://img.shields.io/travis/jlustigy/coronagraph/master.svg?style=flat"/></a>
  <a href="http://coronagraph.readthedocs.io/en/latest/"><img src="https://readthedocs.org/projects/coronagraph/badge/?version=latest"/></a>
  <a href="https://github.com/jlustigy/coronagraph/blob/master/LICENSE"><img src="http://img.shields.io/badge/license-MIT-blue.svg?style=flat"/></a>
  <a href="https://coveralls.io/github/jlustigy/coronagraph?branch=master"><img src="https://coveralls.io/repos/github/jlustigy/coronagraph/badge.svg?branch=master&style=flat"/></a>
</p>

Documentation
=============

Please refer to the [code documentation](http://coronagraph.readthedocs.io/en/latest/) on Read the Docs. 

Installation
============

The simplest option is to install using `pip`:

```bash
   pip install coronagraph
```

Users may also clone the repository on Github:

```bash
   git clone https://github.com/jlustigy/coronagraph.git
   cd coronagraph
   python setup.py
```

Note
====
If you use this model in your own research please cite [Robinson et al (2016)](http://adsabs.harvard.edu/cgi-bin/bib_query?arXiv:1507.00777) and include the following acknowledgement: "This work made use of the Python coronagraph noise model, developed by J. Lustig-Yaeger and available at https://github.com/jlustigy/coronagraph/".

==> coronagraph-1.0.tar.gz: coronagraph-1.0/README.md <==
<p align="center">
  <img width = "450" src="https://github.com/jlustigy/coronagraph/blob/master/docs/_static/logo6.png?raw=true"/>
  <br>
  A Python noise model for directly imaging exoplanets with coronagraph equipped telescopes.  
</p>

<p align="center">
  <a href="https://travis-ci.org/jlustigy/coronagraph"><img src="http://img.shields.io/travis/jlustigy/coronagraph/master.svg?style=flat"/></a>
  <a href="https://jlustigy.github.io/coronagraph/"><img src="https://img.shields.io/badge/read-the_docs-blue.svg?style=flat"/></a>
  <a href="http://joss.theoj.org/papers/29a123d0178ea95da358dafc0282e8f7"><img src="http://joss.theoj.org/papers/29a123d0178ea95da358dafc0282e8f7/status.svg"></a>
  <a href="https://github.com/jlustigy/coronagraph/blob/master/LICENSE"><img src="http://img.shields.io/badge/license-MIT-blue.svg?style=flat"/></a>
  <a href="https://coveralls.io/github/jlustigy/coronagraph?branch=master"><img src="https://coveralls.io/repos/github/jlustigy/coronagraph/badge.svg?branch=master&style=flat"/></a>
</p>

Documentation
=============

Please refer to the [code documentation](https://jlustigy.github.io/coronagraph/) for examples, API, and more. 

Installation
============

The simplest option is to install using `pip`:

```bash
   pip install coronagraph
```

Users may also clone the repository on Github:

```bash
   git clone https://github.com/jlustigy/coronagraph.git
   cd coronagraph
   python setup.py
```

Note
====
If you use this model in your own research please cite [Robinson et al (2016)](http://adsabs.harvard.edu/cgi-bin/bib_query?arXiv:1507.00777) and include the following acknowledgement: "This work made use of the Python coronagraph noise model, developed by J. Lustig-Yaeger and available at https://github.com/jlustigy/coronagraph/".
